@@ -1,5 +1,5 @@
 use strict;
-use warnings;
+#use warnings;
 
 package RDF::Notation3::Template::TReader;
 
